@@ -79,7 +79,12 @@ find_domain <- function(event) {
 
 # Force url to be opened by Chromium browser
 browse_url <- function(path, chromote) {
-  url <- chromote$url(path)
+  if (grepl("^[a-zA-Z][a-zA-Z0-9+.-]*://", path)) {
+    # `path` is already a full URL
+    url <- path
+  } else {
+    url <- chromote$url(path)
+  }
 
   browser <- chromote$get_browser()
   if (inherits(browser, "Chrome")) {
@@ -88,7 +93,11 @@ browse_url <- function(path, chromote) {
     product <- chromote$Browser$getVersion(wait_ = TRUE)$product
 
     # And if not chrome-headless-shell (which doesn't have a UI we can use)
-    if (!grepl("HeadlessChrome", product, fixed = TRUE)) {
+    if (grepl("HeadlessChrome", product, fixed = TRUE)) {
+      cli::cli_warn(
+        "Cannot open a browser window with {.field chrome-headless-shell}, using your default browser instead."
+      )
+    } else {
       # Quote the path if using a non-windows machine
       if (!is_windows()) browser_path <- shQuote(browser_path)
       utils::browseURL(url, browser_path)
